@@ -206,6 +206,26 @@ class StructMemberAttributes(object):
                 raise AttributeValidationError('len == ' + repr(JsonFloat(self.len_eq, 6)))
 
 
+# Typedef type (type plus attributes)
+class Typedef(object):
+    __slots__ = ('typeName', 'type', 'attr', 'doc')
+
+    def __init__(self, type, attr = None, typeName = None, doc = None):
+        self.typeName = 'typedef' if typeName is None else typeName
+        self.type = type
+        self.attr = attr
+        self.doc = [] if doc is None else doc
+
+    def validateAttr(self, attr):
+        self.type.validateAttr(attr)
+
+    def validate(self, value, mode = VALIDATE_DEFAULT, _member = ()):
+        result = self.type.validate(value, mode, _member)
+        if self.attr is not None:
+            self.attr.validate(result, _member)
+        return result
+
+
 # Struct member
 class StructMember(object):
     __slots__ = ('name', 'type', 'isOptional', 'attr', 'doc')
@@ -223,7 +243,7 @@ class TypeStruct(object):
     __slots__ = ('typeName', 'isUnion', '_members', '_membersDict', 'doc')
 
     def __init__(self, typeName = None, isUnion = False, doc = None):
-        self.typeName = typeName if typeName else ('union' if isUnion else 'struct')
+        self.typeName = ('union' if isUnion else 'struct') if typeName is None else typeName
         self.isUnion = isUnion
         self._members = []
         self._membersDict = {}
